{ config, lib, pkgs, modulesPath, ... }:

{
  imports =
    [ (modulesPath + "/installer/scan/not-detected.nix")
    ];

  boot.initrd.availableKernelModules = [ "xhci_pci" "ahci" "nvme" ];
  boot.initrd.kernelModules = [ "dm-snapshot" ];
  boot.kernelModules = [ "kvm-amd" ];
  boot.extraModulePackages = [ ];

  fileSystems."/" =
    { device = "tmpfs";
      fsType = "tmpfs";
    };

  fileSystems."/nix/.rw-store" =
    { device = "tmpfs";
      fsType = "tmpfs";
    };

  fileSystems."/nix/.ro-store" =
    { device = "/nix/store/fz3m5p11iiy094iradd3y6l76dfxf3yl-squashfs.img (deleted)";
      fsType = "squashfs";
      options = [ "loop" ];
    };

   fileSystems."/nix/store" =
    { device = "overlay";
      fsType = "overlay";
    };

  fileSystems."/etc" =
    { device = "overlay";
      fsType = "overlay";
    };

  fileSystems."/mnt" =
    { device = "/dev/disk/by-uuid/3910b9f0-99b6-4a35-a308-2c2c3ec33ba3";
      fsType = "ext4";
    };

  fileSystems."/mnt/boot" =
    { device = "/dev/disk/by-uuid/AC28-2C41";
      fsType = "vfat";
      options = [ "fmask=0077" "dmask=0077" ];
    };

  swapDevices = [ ];

  # Enables DHCP on each ethernet and wireless interface. In case of scripted networking
  # (the default) this is the recommended approach. When using systemd-networkd it's
  # still possible to use this option, but it's recommended to use it in conjunction
  # with explicit per-interface declarations with `networking.interfaces.<interface>.useDHCP`.
  networking.useDHCP = lib.mkDefault true;
  # networking.interfaces.enp35s0.useDHCP = lib.mkDefault true;

  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
  boot.swraid.enable = true;
}
